import { BasicColumn, FormSchema } from '@/components/Table';
import { ManOutlined } from '@ant-design/icons-vue';
import { color } from 'echarts';

export const tabTableColumn: BasicColumn[] = [
  {
    title: '指标主体名称',
    dataIndex: 'name',
  },
  {
    title: '指标英文名',
    dataIndex: 'name',
  },
  {
    title: '指标描述',
    dataIndex: 'txt',
  },
  {
    title: '指标类型',
    dataIndex: 'type',
  },
  {
    title: '开发状态',
    dataIndex: 'status',
  },
  {
    title: '创建者',
    dataIndex: 'createdBy',
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    sorter: true,
  },
];
export const tabTableFormSchema: FormSchema[] = [
  {
    field: '指标名称/英文名搜索',
    component: 'Input',
    componentProps: {
      placeholder: '指标名称/英文名搜索',
      style: {
        marginLeft: '10px',
      },
    },
  },
  {
    field: '开发状态',
    component: 'Select',
    componentProps: {
      placeholder: '开发状态',
      options: [
        { label: '开发中', value: '1' },
        { label: '已发布', value: '2' },
      ],
      style: {
        marginLeft: '20px',
      },
    },
  },
  {
    field: '指标类型',
    component: 'Select',
    componentProps: {
      placeholder: '指标类型',
      options: [
        { label: '类型1', value: '1' },
        { label: '类型2', value: '2' },
      ],
      style: {
        marginLeft: '30px',
      },
    },
  },
  {
    field: '更新时间范围',
    component: 'DatePicker',
    componentProps: {
      placeholder: '更新时间范围',
      style: {
        marginLeft: '40px',
      },
    },
  },
];
export const addTabFormSchema: FormSchema[] = [
  {
    label: '选择指标类型',
    field: 'type',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: '原子指标', value: '1' },
        { label: '衍生指标', value: '2' },
        { label: '复合指标', value: '3' },
      ],
    },
  },
  {
    label: '原子指标是某一业务行为时间下的度量,是业务定义中不可拆分的指标,例如销售额。',
    field: 'atom',
    component: 'BasicTitle',
    ifShow: ({ values }) => {
      return values.type === '1';
    },
  },
  {
    label: '衍生指标是原子指标通过添加维度、过滤条件卷积而成,例如全国各城市7月份销售额',
    field: 'derived',
    component: 'BasicTitle',
    ifShow: ({ values }) => {
      return values.type === '2';
    },
  },
  {
    label:
      '复合指标是由一个或多个衍生指标叠加计算而成,其中的维度、过滤条件均继承于衍生指标,例如利润=销售额-成本。',
    field: 'compound',
    component: 'BasicTitle',
    ifShow: ({ values }) => {
      return values.type === '3';
    },
  },
];
